const path = require('path');
const rootPath = path.resolve(process.env.PWD);

var generate = require('./../src/file-copy-parse').generate;

//gene  rate({
    // sourceFiles: path.join(rootPath, 'test.html'),
    // sourceRoot: path.join(rootPath),
    // targetRoot: path.join(rootPath, 'out')
//})

var templateString = `
var thisIsMyLoveSong; // var templateString = 
var myHateSong = 'does not exist';//     ssup my dude?!
var awesomeness;
    //this is comment 1
    // this is comment2
    Just chillin'
 `;

var anotherTemplateString = `var thisIsMyLoveSong; // var templateString = 
var myHateSong = 'does not exist';//     ssup my dude?!
var awesomeness;
    ``//this is comment 1
    // this is comment2
    Just chillin'
 `;

var testUrl = '//unclebob.com';

'use strict';

const fs = require('fs');
const glob = require('glob');

module.exports = {
    generate:generate
};

/**
 * @class generate
 * @description Generate a compressed file at a target location, and replace any template literal variables present with a specific value
 * @param {array|object} params - The configuration for one or more sources and destinations
 * @param {string|array} params.sourceFiles - Either the list of files you need to minify and cache bust, or a globbing pattern
 * @param {string} params.sourceRoot - The root folder (lowest common folder) that the source files are located in
 * @param {string} params.targetRoot - The root folder (lowest common folder) that the processed files should be written to
 * @param {object|function} [params.templateVars = {}] - An object (or function returning an object) that will contain the values associated with any template literal variables included in the source file
 * @returns {void}
 * */
function generate(params) {
    const options = (params instanceof Array) ? params : [params];

    options.map(function(option) {
        const files = (option.sourceFiles instanceof Array) ? option.sourceFiles : glob.sync(option.sourceFiles);

        files.forEach(file => {
            let markupString = fs.readFileSync(file).toString();

            /* Detect what type of template variables property has been set */
            const templateVars = typeof option.templateVars === 'function' ? option.templateVars() :
                typeof option.templateVars === 'object' ? option.templateVars : {};

            /* Minify the markup (most conservative minification possible) */
            markupString = markupString.replace(/(\s){2,}/g, '');

            markupString = formatTemplateVars(markupString, templateVars);

            write(file.replace(option.sourceRoot, option.targetRoot), markupString);
        });
    });
}

generate.prototype.apply = (compiler) => {
    compiler.plugin('done', function() {
        console.log('Webpack template parser finished');
    });
};

function write(target, markup) {
    const pathArray = target.split('/');
    let path = `${pathArray.shift()}`;
    const recurse = function() {
        fs.lstat(path, function(err) {
            if(err && path !== '.' && path !== '') {
                try{
                    fs.mkdirSync(path);
                }
                catch(err) {}
            }

            if(pathArray[1]) {
                path = `${path}/${pathArray.shift()}`;
                recurse();
            }
            else {
                fs.writeFileSync(target, markup);
            }
        });
    };

    recurse();
}

function formatTemplateVars(string, templateVars) {
    let returnString = string;
    const matches = returnString.match(/\$\{[\w\-\.]{1,}\}/g) || [];

    matches.forEach(match => {
        const matchArray = match.replace(/[\$\{\}}]/g, '').split('.');

        let requiredValue = templateVars[matchArray[0]];
        matchArray.reduce((firstItem, nextItem) => {
            requiredValue = requiredValue && requiredValue[nextItem];
            return requiredValue;
        });

        if (requiredValue) {
            returnString = returnString.replace(match, requiredValue);
        }
    });

    return returnString;
}

var myFile = fs.readFileSync('./test.html').toString();

console.log(myFile.match(/(\/\/)(.*?)(\s){2,}/))
